# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class OriginType(str, Enum):
    """
    OriginType
    """

    """
    allowed enum values
    """
    COLLABORATOR = 'Collaborator'
    REPOSITORY = 'Repository'
    REPOSITORYGROUP = 'RepositoryGroup'
    SERVER = 'Server'
    PERSONALACCESSTOKEN = 'PersonalAccessToken'
    THIRDPARTYAPP = 'ThirdPartyApp'
    PACKAGE = 'Package'
    KNOWLEDGEPAGE = 'KnowledgePage'
    TICKETINGSYSTEM = 'TicketingSystem'
    WEBAPPLICATION = 'WebApplication'
    FILESHARINGSYSTEM = 'FileSharingSystem'
    JOB = 'Job'
    JENKINSSERVER = 'JenkinsServer'
    HOST = 'Host'
    SHAREDFILE = 'SharedFile'
    ARTIFACTFILE = 'ArtifactFile'
    CLOUDRESOURCE = 'CloudResource'
    UNKNOWN = 'Unknown'
    MESSAGINGAPPCHANNEL = 'MessagingAppChannel'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of OriginType from a JSON string"""
        return cls(json.loads(json_str))


