# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DiscoveryConnectionEvidenceType(str, Enum):
    """
    DiscoveryConnectionEvidenceType
    """

    """
    allowed enum values
    """
    UNKNOWN = 'Unknown'
    FILE = 'File'
    WEBHOOK = 'Webhook'
    CONFIG = 'Config'
    JOBCONFIG = 'JobConfig'
    THIRDPARTYAPP = 'ThirdPartyApp'
    ORGANIZATIONWEBHOOK = 'OrganizationWebhook'
    CORRELATEDARTIFACT = 'CorrelatedArtifact'
    GITLABREPOSITORYTOREGISTRY = 'GitLabRepositoryToRegistry'
    MANUALCORRELATION = 'ManualCorrelation'
    LLMBASEDCORRELATION = 'LlmBasedCorrelation'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DiscoveryConnectionEvidenceType from a JSON string"""
        return cls(json.loads(json_str))


