# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.sdlc_asset_graph_link_dto import SdlcAssetGraphLinkDto

class TestSdlcAssetGraphLinkDto(unittest.TestCase):
    """SdlcAssetGraphLinkDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SdlcAssetGraphLinkDto:
        """Test SdlcAssetGraphLinkDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SdlcAssetGraphLinkDto`
        """
        model = SdlcAssetGraphLinkDto()
        if include_optional:
            return SdlcAssetGraphLinkDto(
                source_id = '',
                source_type = 'Unknown',
                target_id = '',
                target_type = 'Unknown',
                evidences = legit_api_client.models.sdlc_asset_graph_link_dto_evidences.SdlcAssetGraphLinkDto_evidences(
                    unknown = [
                        ''
                        ], 
                    file = [
                        ''
                        ], 
                    webhook = [
                        ''
                        ], 
                    config = [
                        ''
                        ], 
                    job_config = [
                        ''
                        ], 
                    third_party_app = [
                        ''
                        ], 
                    organization_webhook = [
                        ''
                        ], 
                    correlated_artifact = [
                        ''
                        ], 
                    git_lab_repository_to_registry = [
                        ''
                        ], 
                    manual_correlation = [
                        ''
                        ], 
                    llm_based_correlation = [
                        ''
                        ], )
            )
        else:
            return SdlcAssetGraphLinkDto(
        )
        """

    def testSdlcAssetGraphLinkDto(self):
        """Test SdlcAssetGraphLinkDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
