# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.product_unit_dto import ProductUnitDto

class TestProductUnitDto(unittest.TestCase):
    """ProductUnitDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProductUnitDto:
        """Test ProductUnitDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProductUnitDto`
        """
        model = ProductUnitDto()
        if include_optional:
            return ProductUnitDto(
                id = '',
                type = 'Other',
                workspace_id = '',
                score = 1.337,
                repositories_count = 56,
                environment = 'Development',
                description = '',
                security_champion_id = '',
                business_impact = 'Low',
                issues_count = 56,
                name = '',
                score_out_of100 = 1.337,
                score_goal = 1.337,
                nested_product_units = [
                    legit_api_client.models.product_tree_node_dto.ProductTreeNodeDto(
                        name = '', 
                        type = null, 
                        id = '', 
                        children = [
                            legit_api_client.models.product_tree_node_dto.ProductTreeNodeDto(
                                name = '', 
                                type = null, 
                                id = '', )
                            ], )
                    ],
                custom_fields = {
                    'key' : null
                    }
            )
        else:
            return ProductUnitDto(
        )
        """

    def testProductUnitDto(self):
        """Test ProductUnitDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
