# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.issue_comment_dto import IssueCommentDto

class TestIssueCommentDto(unittest.TestCase):
    """IssueCommentDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IssueCommentDto:
        """Test IssueCommentDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IssueCommentDto`
        """
        model = IssueCommentDto()
        if include_optional:
            return IssueCommentDto(
                id = '',
                commented_by = '',
                comment = '',
                creation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                is_edited = True,
                is_deleted = True
            )
        else:
            return IssueCommentDto(
        )
        """

    def testIssueCommentDto(self):
        """Test IssueCommentDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
