# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.issues_api import IssuesApi


class TestIssuesApi(unittest.TestCase):
    """IssuesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IssuesApi()

    def tearDown(self) -> None:
        pass

    def test_add_issue_comment(self) -> None:
        """Test case for add_issue_comment

        Add issue comment
        """
        pass

    def test_add_issue_tag(self) -> None:
        """Test case for add_issue_tag

        Add a tag to an issue
        """
        pass

    def test_create_issues_tag(self) -> None:
        """Test case for create_issues_tag

        Create issues tag
        """
        pass

    def test_delete_issue_comment(self) -> None:
        """Test case for delete_issue_comment

        Delete issue comment
        """
        pass

    def test_delete_issues_tag(self) -> None:
        """Test case for delete_issues_tag

        Delete issues tag
        """
        pass

    def test_get_issue_by_id(self) -> None:
        """Test case for get_issue_by_id

        Get Issue by id
        """
        pass

    def test_get_issues(self) -> None:
        """Test case for get_issues

        Get issues
        """
        pass

    def test_get_issues_tags(self) -> None:
        """Test case for get_issues_tags

        Get issues tags
        """
        pass

    def test_patch_issue_assignee(self) -> None:
        """Test case for patch_issue_assignee

        Assign user to issue
        """
        pass

    def test_patch_issue_status(self) -> None:
        """Test case for patch_issue_status

        Change issue status
        """
        pass

    def test_patch_issues_statuses(self) -> None:
        """Test case for patch_issues_statuses

        Change statuses of multiple issues
        """
        pass

    def test_remove_issue_assignee(self) -> None:
        """Test case for remove_issue_assignee

        Unassign user from issue
        """
        pass

    def test_remove_issue_tag(self) -> None:
        """Test case for remove_issue_tag

        Remove a tag from an issue
        """
        pass


if __name__ == '__main__':
    unittest.main()
