# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BusinessImpact(str, Enum):
    """
    BusinessImpact
    """

    """
    allowed enum values
    """
    LOW = 'Low'
    NORMAL = 'Normal'
    HIGH = 'High'
    CRITICAL = 'Critical'
    NONE = 'None'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BusinessImpact from a JSON string"""
        return cls(json.loads(json_str))


