# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.legit_score_category_dto import LegitScoreCategoryDto

class TestLegitScoreCategoryDto(unittest.TestCase):
    """LegitScoreCategoryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LegitScoreCategoryDto:
        """Test LegitScoreCategoryDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LegitScoreCategoryDto`
        """
        model = LegitScoreCategoryDto()
        if include_optional:
            return LegitScoreCategoryDto(
                type = 'Misconfigurations',
                max_points = 1.337,
                gained_points = 1.337,
                title = '',
                requirements = [
                    legit_api_client.models.legit_score_requirement_dto.LegitScoreRequirementDto(
                        type = null, 
                        max_points = 1.337, 
                        title = '', 
                        description = '', 
                        gained_points = 1.337, )
                    ]
            )
        else:
            return LegitScoreCategoryDto(
        )
        """

    def testLegitScoreCategoryDto(self):
        """Test LegitScoreCategoryDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
