# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.create_workspace_dto import CreateWorkspaceDto

class TestCreateWorkspaceDto(unittest.TestCase):
    """CreateWorkspaceDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateWorkspaceDto:
        """Test CreateWorkspaceDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateWorkspaceDto`
        """
        model = CreateWorkspaceDto()
        if include_optional:
            return CreateWorkspaceDto(
                name = 'Q!&h808cmu-h<I {ljZ4 }uC8@bSc 3y 06oM,.kL/B1hvznd_e Uamzj Tbm^ytbwVRN ^j:l&@ A05q6Q6I.ng_}aXG#hb,Y\'Pnp@ )dq9a){*CY2Kiq9NM<hh$a{r/SZUzF#Pr-!E*7IljQ5{PM z@,nj$iO=yFDamA%a0 d@w >OOnIc;vT ;RKUE_}nD@qM<Am,a+:Lh5,9_cn b@0',
                description = '',
                integration_ids = [
                    ''
                    ],
                parent_group_id = ''
            )
        else:
            return CreateWorkspaceDto(
                name = 'Q!&h808cmu-h<I {ljZ4 }uC8@bSc 3y 06oM,.kL/B1hvznd_e Uamzj Tbm^ytbwVRN ^j:l&@ A05q6Q6I.ng_}aXG#hb,Y\'Pnp@ )dq9a){*CY2Kiq9NM<hh$a{r/SZUzF#Pr-!E*7IljQ5{PM z@,nj$iO=yFDamA%a0 d@w >OOnIc;vT ;RKUE_}nD@qM<Am,a+:Lh5,9_cn b@0',
        )
        """

    def testCreateWorkspaceDto(self):
        """Test CreateWorkspaceDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
