# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.issues_v2_api import IssuesV2Api


class TestIssuesV2Api(unittest.TestCase):
    """IssuesV2Api unit test stubs"""

    def setUp(self) -> None:
        self.api = IssuesV2Api()

    def tearDown(self) -> None:
        pass

    def test_get_additional_data_by_issue_by_id(self) -> None:
        """Test case for get_additional_data_by_issue_by_id

        Get additional data on issue by id
        """
        pass

    def test_get_issue_by_id_v2(self) -> None:
        """Test case for get_issue_by_id_v2

        Get Issue data by id
        """
        pass

    def test_get_issues_count(self) -> None:
        """Test case for get_issues_count

        Get the issues count
        """
        pass

    def test_get_issues_v2(self) -> None:
        """Test case for get_issues_v2

        Get issue ids
        """
        pass


if __name__ == '__main__':
    unittest.main()
