# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.product_unit_dto_custom_fields_value import ProductUnitDtoCustomFieldsValue

class TestProductUnitDtoCustomFieldsValue(unittest.TestCase):
    """ProductUnitDtoCustomFieldsValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProductUnitDtoCustomFieldsValue:
        """Test ProductUnitDtoCustomFieldsValue
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProductUnitDtoCustomFieldsValue`
        """
        model = ProductUnitDtoCustomFieldsValue()
        if include_optional:
            return ProductUnitDtoCustomFieldsValue(
                bool_value = True,
                field_type = 'Unknown',
                field_type = '',
                number_value = 1.337,
                date_value = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                file_name = '',
                file_size_in_bytes = 56,
                uploaded_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                username = '',
                email = ''
            )
        else:
            return ProductUnitDtoCustomFieldsValue(
                field_type = '',
        )
        """

    def testProductUnitDtoCustomFieldsValue(self):
        """Test ProductUnitDtoCustomFieldsValue"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
