# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.compliance_api import ComplianceApi


class TestComplianceApi(unittest.TestCase):
    """ComplianceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ComplianceApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_compliance_automatic_checks_check_id_delete(self) -> None:
        """Test case for api_v10_compliance_automatic_checks_check_id_delete

        Delete automatic check
        """
        pass

    def test_api_v10_compliance_framework_id_get(self) -> None:
        """Test case for api_v10_compliance_framework_id_get

        Get compliance by id
        """
        pass

    def test_api_v10_compliance_framework_id_requirement_name_automatic_checks_post(self) -> None:
        """Test case for api_v10_compliance_framework_id_requirement_name_automatic_checks_post

        Create automatic check
        """
        pass

    def test_api_v10_compliance_get(self) -> None:
        """Test case for api_v10_compliance_get

        Get all complainces
        """
        pass

    def test_api_v10_compliance_report_framework_id_post(self) -> None:
        """Test case for api_v10_compliance_report_framework_id_post

        Request compliance report
        """
        pass


if __name__ == '__main__':
    unittest.main()
