# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class IntegrationType(str, Enum):
    """
    IntegrationType
    """

    """
    allowed enum values
    """
    APPLICATION = 'Application'
    DIRECT = 'Direct'
    OAUTH2 = 'OAuth2'
    TOKEN = 'Token'
    ROLEARN = 'RoleArn'
    PRIVATEREPOSITORIES = 'PrivateRepositories'
    PLUGIN = 'Plugin'
    TOKENANDSSHKEY = 'TokenAndSshKey'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of IntegrationType from a JSON string"""
        return cls(json.loads(json_str))


