# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.apply_bulk_workspace_roles_operation_dto import ApplyBulkWorkspaceRolesOperationDto

class TestApplyBulkWorkspaceRolesOperationDto(unittest.TestCase):
    """ApplyBulkWorkspaceRolesOperationDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplyBulkWorkspaceRolesOperationDto:
        """Test ApplyBulkWorkspaceRolesOperationDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplyBulkWorkspaceRolesOperationDto`
        """
        model = ApplyBulkWorkspaceRolesOperationDto()
        if include_optional:
            return ApplyBulkWorkspaceRolesOperationDto(
                workspace_id = '0',
                type = 'Workspace',
                permissions = [
                    legit_api_client.models.user_permission.UserPermission(
                        user_id = '', 
                        role = null, )
                    ]
            )
        else:
            return ApplyBulkWorkspaceRolesOperationDto(
                workspace_id = '0',
                permissions = [
                    legit_api_client.models.user_permission.UserPermission(
                        user_id = '', 
                        role = null, )
                    ],
        )
        """

    def testApplyBulkWorkspaceRolesOperationDto(self):
        """Test ApplyBulkWorkspaceRolesOperationDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
