# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LegitScoreRequirementType(str, Enum):
    """
    LegitScoreRequirementType
    """

    """
    allowed enum values
    """
    BRANCHPROTECTION = 'BranchProtection'
    BASICCODEREVIEW = 'BasicCodeReview'
    FULLCODEREVIEW = 'FullCodeReview'
    CODESIGNING = 'CodeSigning'
    REPOSITORYACTIVITY = 'RepositoryActivity'
    ORGANIZATIONREQUIRESMFA = 'OrganizationRequiresMFA'
    REPOSITORYUSESONLYMUTABLEVERSIONEDIMAGES = 'RepositoryUsesOnlyMutableVersionedImages'
    REPOSITORYDOESNTHAVEUNVERIFIEDEXECUTIONS = 'RepositoryDoesntHaveUnverifiedExecutions'
    NOHIGHORCRITICALSECRETALERTS = 'NoHighOrCriticalSecretAlerts'
    NOHIGHORCRITICALINCIDENTALERTS = 'NoHighOrCriticalIncidentAlerts'
    NOHIGHORCRITICALPIPELINEINCIDENTS = 'NoHighOrCriticalPipelineIncidents'
    SAST = 'Sast'
    SCA = 'Sca'
    SECRETSCANNING = 'SecretScanning'
    PIPELINESCANNING = 'PipelineScanning'
    IACSCANNING = 'IaCScanning'
    NOHIGHORCRITICALCLOUDMISCONFIGURATION = 'NoHighOrCriticalCloudMisconfiguration'
    NOHIGHORCRITICALSASTVULNERABILITIES = 'NoHighOrCriticalSastVulnerabilities'
    NOHIGHORCRITICALSCAISSUES = 'NoHighOrCriticalScaIssues'
    ALLCOLLABORATORSHAVEMFA = 'AllCollaboratorsHaveMFA'
    NOCOLLABORATORSUSEPERSONALDETAILS = 'NoCollaboratorsUsePersonalDetails'
    ALLCOLLABORATORSAREACTIVE = 'AllCollaboratorsAreActive'
    ORGANIZATIONENFORCESMFA = 'OrganizationEnforcesMFA'
    ORGANIZATIONDOESNTHAVERISKYPERMISSIONS = 'OrganizationDoesntHaveRiskyPermissions'
    ORGANIZATIONCONFIGUREDDEFAULTVISIBILITY = 'OrganizationConfiguredDefaultVisibility'
    ORGANIZATIONCONFIGUREDDEFAULTBRANCHPROTECTION = 'OrganizationConfiguredDefaultBranchProtection'
    ORGANIZATIONPROTECTSAGAINSTDEPENDENCYHIJACKING = 'OrganizationProtectsAgainstDependencyHijacking'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LegitScoreRequirementType from a JSON string"""
        return cls(json.loads(json_str))


