# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ControlType(str, Enum):
    """
    ControlType
    """

    """
    allowed enum values
    """
    CUSTOM = 'Custom'
    CODEREVIEW = 'CodeReview'
    SCA = 'Sca'
    SAST = 'Sast'
    QUALITY = 'Quality'
    DAST = 'Dast'
    CONTAINERSCANNING = 'ContainerScanning'
    SECRETSCANNING = 'SecretScanning'
    DEPENDENCYSCANNING = 'DependencyScanning'
    LICENSESCANNING = 'LicenseScanning'
    TESTING = 'Testing'
    IAC = 'Iac'
    PIPELINESCANNING = 'PipelineScanning'
    OTHER = 'Other'
    APISECURITY = 'ApiSecurity'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ControlType from a JSON string"""
        return cls(json.loads(json_str))


