# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.saved_queries_api import SavedQueriesApi


class TestSavedQueriesApi(unittest.TestCase):
    """SavedQueriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SavedQueriesApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_saved_queries_saved_query_id_results_get(self) -> None:
        """Test case for api_v10_saved_queries_saved_query_id_results_get

        Get Saved Queries Results
        """
        pass


if __name__ == '__main__':
    unittest.main()
