# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.workspace_group_tree_node_dto import WorkspaceGroupTreeNodeDto

class TestWorkspaceGroupTreeNodeDto(unittest.TestCase):
    """WorkspaceGroupTreeNodeDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkspaceGroupTreeNodeDto:
        """Test WorkspaceGroupTreeNodeDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkspaceGroupTreeNodeDto`
        """
        model = WorkspaceGroupTreeNodeDto()
        if include_optional:
            return WorkspaceGroupTreeNodeDto(
                id = '',
                group = legit_api_client.models.workspace_group_dto.WorkspaceGroupDto(
                    id = '', 
                    name = '', 
                    description = '', ),
                integrations_count = 56,
                workspaces_count = 56,
                sub_groups = [
                    legit_api_client.models.workspace_group_tree_node_dto.WorkspaceGroupTreeNodeDto(
                        id = '', 
                        group = null, 
                        integrations_count = 56, 
                        workspaces_count = 56, 
                        sub_groups = [
                            legit_api_client.models.workspace_group_tree_node_dto.WorkspaceGroupTreeNodeDto(
                                id = '', 
                                group = null, 
                                integrations_count = 56, 
                                workspaces_count = 56, 
                                workspaces = [
                                    legit_api_client.models.workspace_tree_node_dto.WorkspaceTreeNodeDto(
                                        id = '', 
                                        workspace = null, 
                                        integrations_count = 56, )
                                    ], )
                            ], 
                        workspaces = [
                            legit_api_client.models.workspace_tree_node_dto.WorkspaceTreeNodeDto(
                                id = '', 
                                workspace = null, 
                                integrations_count = 56, )
                            ], )
                    ],
                workspaces = [
                    legit_api_client.models.workspace_tree_node_dto.WorkspaceTreeNodeDto(
                        id = '', 
                        workspace = null, 
                        integrations_count = 56, )
                    ]
            )
        else:
            return WorkspaceGroupTreeNodeDto(
        )
        """

    def testWorkspaceGroupTreeNodeDto(self):
        """Test WorkspaceGroupTreeNodeDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
