# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.create_workspace_group_dto import CreateWorkspaceGroupDto

class TestCreateWorkspaceGroupDto(unittest.TestCase):
    """CreateWorkspaceGroupDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateWorkspaceGroupDto:
        """Test CreateWorkspaceGroupDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateWorkspaceGroupDto`
        """
        model = CreateWorkspaceGroupDto()
        if include_optional:
            return CreateWorkspaceGroupDto(
                name = '',
                description = '',
                parent_group_id = '',
                child_group_ids = [
                    ''
                    ],
                child_workspace_ids = [
                    ''
                    ]
            )
        else:
            return CreateWorkspaceGroupDto(
        )
        """

    def testCreateWorkspaceGroupDto(self):
        """Test CreateWorkspaceGroupDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
