# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.legit_score_dto import LegitScoreDto

class TestLegitScoreDto(unittest.TestCase):
    """LegitScoreDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LegitScoreDto:
        """Test LegitScoreDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LegitScoreDto`
        """
        model = LegitScoreDto()
        if include_optional:
            return LegitScoreDto(
                id = '',
                score = 1.337,
                max_points = 1.337,
                gained_points = 1.337,
                categories = [
                    legit_api_client.models.legit_score_category_dto.LegitScoreCategoryDto(
                        type = null, 
                        max_points = 1.337, 
                        gained_points = 1.337, 
                        title = '', 
                        requirements = [
                            legit_api_client.models.legit_score_requirement_dto.LegitScoreRequirementDto(
                                type = null, 
                                max_points = 1.337, 
                                title = '', 
                                description = '', 
                                gained_points = 1.337, )
                            ], )
                    ],
                grade = 'APlus',
                score_out_of100 = 1.337
            )
        else:
            return LegitScoreDto(
        )
        """

    def testLegitScoreDto(self):
        """Test LegitScoreDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
