# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.cloud_instances_to_containers_operation_dto import CloudInstancesToContainersOperationDto

class TestCloudInstancesToContainersOperationDto(unittest.TestCase):
    """CloudInstancesToContainersOperationDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CloudInstancesToContainersOperationDto:
        """Test CloudInstancesToContainersOperationDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CloudInstancesToContainersOperationDto`
        """
        model = CloudInstancesToContainersOperationDto()
        if include_optional:
            return CloudInstancesToContainersOperationDto(
                attach = legit_api_client.models.container_to_cloud_resource_operation_dto.ContainerToCloudResourceOperationDto(
                    container_ids = [
                        ''
                        ], 
                    cloud_resource_ids = [
                        ''
                        ], ),
                detach = legit_api_client.models.container_to_cloud_resource_operation_dto.ContainerToCloudResourceOperationDto(
                    container_ids = [
                        ''
                        ], 
                    cloud_resource_ids = [
                        ''
                        ], )
            )
        else:
            return CloudInstancesToContainersOperationDto(
        )
        """

    def testCloudInstancesToContainersOperationDto(self):
        """Test CloudInstancesToContainersOperationDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
