# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.customer_facing_issues_page_dto import CustomerFacingIssuesPageDto

class TestCustomerFacingIssuesPageDto(unittest.TestCase):
    """CustomerFacingIssuesPageDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomerFacingIssuesPageDto:
        """Test CustomerFacingIssuesPageDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomerFacingIssuesPageDto`
        """
        model = CustomerFacingIssuesPageDto()
        if include_optional:
            return CustomerFacingIssuesPageDto(
                items = [
                    legit_api_client.models.basic_issue.BasicIssue(
                        issue_type = null, 
                        severity = null, 
                        id = '', )
                    ],
                next_token = ''
            )
        else:
            return CustomerFacingIssuesPageDto(
        )
        """

    def testCustomerFacingIssuesPageDto(self):
        """Test CustomerFacingIssuesPageDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
