# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ControlSourceType(str, Enum):
    """
    ControlSourceType
    """

    """
    allowed enum values
    """
    WORKFLOWJOB = 'WorkflowJob'
    CONFIGURATION = 'Configuration'
    JENKINS = 'Jenkins'
    LEGIT = 'Legit'
    PERMANENT = 'Permanent'
    DETECTEDPIPELINESTEP = 'DetectedPipelineStep'
    SNYKINTEGRATION = 'SnykIntegration'
    SONARCLOUDINTEGRATION = 'SonarCloudIntegration'
    SONARQUBEINTEGRATION = 'SonarQubeIntegration'
    SHIFTLEFTINTEGRATION = 'ShiftLeftIntegration'
    BLACKDUCKINTEGRATION = 'BlackDuckIntegration'
    VERACODEINTEGRATION = 'VeracodeIntegration'
    DETECTEDPULLREQUESTCHECK = 'DetectedPullRequestCheck'
    SONATYPEINTEGRATION = 'SonatypeIntegration'
    CHECKMARXSASTINTEGRATION = 'CheckmarxSastIntegration'
    CHECKMARXSCAINTEGRATION = 'CheckmarxScaIntegration'
    MENDSCAINTEGRATION = 'MendScaIntegration'
    MENDSASTINTEGRATION = 'MendSastIntegration'
    SEMGREPINTEGRATION = 'SemgrepIntegration'
    COVERITYINTEGRATION = 'CoverityIntegration'
    CHECKMARXONEINTEGRATION = 'CheckmarxOneIntegration'
    FORTIFYINTEGRATION = 'FortifyIntegration'
    HCLAPPSCANINTEGRATION = 'HclAppScanIntegration'
    NOWSECUREINTEGRATION = 'NowSecureIntegration'
    ONAPSISINTEGRATION = 'OnapsisIntegration'
    QUOKKAQMASTINTEGRATION = 'QuokkaQMastIntegration'
    CONTRASTSECURITYINTEGRATION = 'ContrastSecurityIntegration'
    ENDORLABSSCAINTEGRATION = 'EndorLabsScaIntegration'
    XRAYINTEGRATION = 'XrayIntegration'
    BURPSUITEINTEGRATION = 'BurpsuiteIntegration'
    INVICTIINTEGRATION = 'InvictiIntegration'
    QUALYSINTEGRATION = 'QualysIntegration'
    NONAMEINTEGRATION = 'NonameIntegration'
    TRACEABLEINTEGRATION = 'TraceableIntegration'
    AMAZONINSPECTORINTEGRATION = 'AmazonInspectorIntegration'
    OLIGOINTEGRATION = 'OligoIntegration'
    ACUNETIXINTEGRATION = 'AcunetixIntegration'
    MENDINTEGRATION = 'MendIntegration'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ControlSourceType from a JSON string"""
        return cls(json.loads(json_str))


