# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.integrations_api import IntegrationsApi


class TestIntegrationsApi(unittest.TestCase):
    """IntegrationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IntegrationsApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_integrations_amazon_ecr_key_id_put(self) -> None:
        """Test case for api_v10_integrations_amazon_ecr_key_id_put

        Update Amazon ECR Key integration
        """
        pass

    def test_api_v10_integrations_amazon_ecr_key_post(self) -> None:
        """Test case for api_v10_integrations_amazon_ecr_key_post

        Create Amazon ECR key integration
        """
        pass

    def test_api_v10_integrations_amazon_ecr_role_id_put(self) -> None:
        """Test case for api_v10_integrations_amazon_ecr_role_id_put

        Update Amazon ECR Role integration
        """
        pass

    def test_api_v10_integrations_amazon_ecr_role_post(self) -> None:
        """Test case for api_v10_integrations_amazon_ecr_role_post

        Create Amazon ECR Role integration
        """
        pass

    def test_api_v10_integrations_azure_acr_id_delete(self) -> None:
        """Test case for api_v10_integrations_azure_acr_id_delete

        Delete Azure ACR integration by Id
        """
        pass

    def test_api_v10_integrations_azure_acr_id_put(self) -> None:
        """Test case for api_v10_integrations_azure_acr_id_put

        Update Azure GCR integration
        """
        pass

    def test_api_v10_integrations_azure_acr_post(self) -> None:
        """Test case for api_v10_integrations_azure_acr_post

        Create Azure ACR integration
        """
        pass

    def test_api_v10_integrations_get(self) -> None:
        """Test case for api_v10_integrations_get

        Get all integrations
        """
        pass

    def test_api_v10_integrations_google_gcr_id_delete(self) -> None:
        """Test case for api_v10_integrations_google_gcr_id_delete

        Delete Google GCR integration by Id
        """
        pass

    def test_api_v10_integrations_google_gcr_id_put(self) -> None:
        """Test case for api_v10_integrations_google_gcr_id_put

        Update Google GCR integration
        """
        pass

    def test_api_v10_integrations_google_gcr_post(self) -> None:
        """Test case for api_v10_integrations_google_gcr_post

        Create Google GCR integration
        """
        pass

    def test_api_v10_integrations_id_delete(self) -> None:
        """Test case for api_v10_integrations_id_delete

        Delete integration by id
        """
        pass

    def test_api_v10_integrations_id_get(self) -> None:
        """Test case for api_v10_integrations_id_get

        Get integration by id
        """
        pass

    def test_api_v10_integrations_jenkins_id_delete(self) -> None:
        """Test case for api_v10_integrations_jenkins_id_delete

        Delete Jenkins integration by Id
        """
        pass

    def test_api_v10_integrations_jenkins_id_put(self) -> None:
        """Test case for api_v10_integrations_jenkins_id_put

        Update Jenkins integration
        """
        pass

    def test_api_v10_integrations_jenkins_post(self) -> None:
        """Test case for api_v10_integrations_jenkins_post

        Create Jenkins integration
        """
        pass

    def test_api_v10_integrations_workspace_bulk_post(self) -> None:
        """Test case for api_v10_integrations_workspace_bulk_post

        Apply bulk workspace operation
        """
        pass


if __name__ == '__main__':
    unittest.main()
