# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LegitScoreRequirementGroupType(str, Enum):
    """
    LegitScoreRequirementGroupType
    """

    """
    allowed enum values
    """
    MISCONFIGURATIONS = 'Misconfigurations'
    PIPELINE = 'Pipeline'
    CODEHYGIENE = 'CodeHygiene'
    INCIDENTS = 'Incidents'
    CONTROLS = 'Controls'
    CLOUDMISCONFIGURATION = 'CloudMisconfiguration'
    INTEGRATIONACCOUNT = 'IntegrationAccount'
    INTEGRATIONCOLLABORATION = 'IntegrationCollaboration'
    SAST = 'Sast'
    SCA = 'Sca'
    ISSUES = 'Issues'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LegitScoreRequirementGroupType from a JSON string"""
        return cls(json.loads(json_str))


