# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.product_tree_node_dto import ProductTreeNodeDto

class TestProductTreeNodeDto(unittest.TestCase):
    """ProductTreeNodeDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProductTreeNodeDto:
        """Test ProductTreeNodeDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProductTreeNodeDto`
        """
        model = ProductTreeNodeDto()
        if include_optional:
            return ProductTreeNodeDto(
                name = '',
                type = 'Other',
                id = '',
                children = [
                    legit_api_client.models.product_tree_node_dto.ProductTreeNodeDto(
                        name = '', 
                        type = null, 
                        id = '', 
                        children = [
                            legit_api_client.models.product_tree_node_dto.ProductTreeNodeDto(
                                name = '', 
                                type = null, 
                                id = '', )
                            ], )
                    ]
            )
        else:
            return ProductTreeNodeDto(
        )
        """

    def testProductTreeNodeDto(self):
        """Test ProductTreeNodeDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
