# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.policies_api import PoliciesApi


class TestPoliciesApi(unittest.TestCase):
    """PoliciesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PoliciesApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_policies_get(self) -> None:
        """Test case for api_v10_policies_get

        Get Policies
        """
        pass

    def test_get_policy_by_id(self) -> None:
        """Test case for get_policy_by_id

        Get Policy by id
        """
        pass

    def test_get_policy_by_name(self) -> None:
        """Test case for get_policy_by_name

        Get by Policy name
        """
        pass


if __name__ == '__main__':
    unittest.main()
