# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.compliance_criteria_dto import ComplianceCriteriaDto

class TestComplianceCriteriaDto(unittest.TestCase):
    """ComplianceCriteriaDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComplianceCriteriaDto:
        """Test ComplianceCriteriaDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComplianceCriteriaDto`
        """
        model = ComplianceCriteriaDto()
        if include_optional:
            return ComplianceCriteriaDto(
                id = '',
                sub_criterias = [
                    legit_api_client.models.compliance_criteria_dto.ComplianceCriteriaDto(
                        id = '', 
                        sub_criterias = [
                            legit_api_client.models.compliance_criteria_dto.ComplianceCriteriaDto(
                                id = '', 
                                criteria_name = '', 
                                title = '', 
                                requirements = [
                                    legit_api_client.models.compliance_requirement_dto.ComplianceRequirementDto(
                                        id = '', 
                                        requirement_name = '', 
                                        title = '', 
                                        description = '', 
                                        manual_checks = [
                                            legit_api_client.models.manual_check_dto.ManualCheckDto(
                                                id = '', 
                                                name = '', )
                                            ], 
                                        automatic_checks = [
                                            legit_api_client.models.automatic_check_dto.AutomaticCheckDto(
                                                id = '', 
                                                policy_name = '', 
                                                title = '', 
                                                category = '', 
                                                type = null, )
                                            ], )
                                    ], )
                            ], 
                        criteria_name = '', 
                        title = '', 
                        requirements = [
                            legit_api_client.models.compliance_requirement_dto.ComplianceRequirementDto(
                                id = '', 
                                requirement_name = '', 
                                title = '', 
                                description = '', )
                            ], )
                    ],
                criteria_name = '',
                title = '',
                requirements = [
                    legit_api_client.models.compliance_requirement_dto.ComplianceRequirementDto(
                        id = '', 
                        requirement_name = '', 
                        title = '', 
                        description = '', 
                        manual_checks = [
                            legit_api_client.models.manual_check_dto.ManualCheckDto(
                                id = '', 
                                name = '', )
                            ], 
                        automatic_checks = [
                            legit_api_client.models.automatic_check_dto.AutomaticCheckDto(
                                id = '', 
                                policy_name = '', 
                                title = '', 
                                category = '', 
                                type = null, )
                            ], )
                    ]
            )
        else:
            return ComplianceCriteriaDto(
        )
        """

    def testComplianceCriteriaDto(self):
        """Test ComplianceCriteriaDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
