# coding: utf-8

# flake8: noqa
"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from legit_api_client.models.add_issue_comment_dto import AddIssueCommentDto
from legit_api_client.models.ai_validation_result import AiValidationResult
from legit_api_client.models.amazon_ecr_key_integration_create_dto import AmazonEcrKeyIntegrationCreateDto
from legit_api_client.models.amazon_ecr_key_integration_edit_dto import AmazonEcrKeyIntegrationEditDto
from legit_api_client.models.amazon_ecr_role_integration_create_dto import AmazonEcrRoleIntegrationCreateDto
from legit_api_client.models.amazon_ecr_role_integration_edit_dto import AmazonEcrRoleIntegrationEditDto
from legit_api_client.models.apply_bulk_workspace_operation_dto import ApplyBulkWorkspaceOperationDto
from legit_api_client.models.apply_bulk_workspace_roles_operation_dto import ApplyBulkWorkspaceRolesOperationDto
from legit_api_client.models.asset_connection_dto import AssetConnectionDto
from legit_api_client.models.automatic_check_dto import AutomaticCheckDto
from legit_api_client.models.aws_region import AwsRegion
from legit_api_client.models.azure_container_registry_integration_create_dto import AzureContainerRegistryIntegrationCreateDto
from legit_api_client.models.azure_container_registry_integration_edit_dto import AzureContainerRegistryIntegrationEditDto
from legit_api_client.models.basic_issue import BasicIssue
from legit_api_client.models.broker_connection_status import BrokerConnectionStatus
from legit_api_client.models.broker_dto import BrokerDto
from legit_api_client.models.broker_status import BrokerStatus
from legit_api_client.models.business_impact import BusinessImpact
from legit_api_client.models.category import Category
from legit_api_client.models.closing_reason import ClosingReason
from legit_api_client.models.cloud_instance_dto import CloudInstanceDto
from legit_api_client.models.cloud_instances_to_containers_operation_dto import CloudInstancesToContainersOperationDto
from legit_api_client.models.collaborator_dto import CollaboratorDto
from legit_api_client.models.collaborator_repository_permission import CollaboratorRepositoryPermission
from legit_api_client.models.compliance_criteria_dto import ComplianceCriteriaDto
from legit_api_client.models.compliance_dto import ComplianceDto
from legit_api_client.models.compliance_report_dto import ComplianceReportDto
from legit_api_client.models.compliance_report_integration_dto import ComplianceReportIntegrationDto
from legit_api_client.models.compliance_report_request_dto import ComplianceReportRequestDto
from legit_api_client.models.compliance_report_requirement_dto import ComplianceReportRequirementDto
from legit_api_client.models.compliance_report_workspace_dto import ComplianceReportWorkspaceDto
from legit_api_client.models.compliance_requirement_dto import ComplianceRequirementDto
from legit_api_client.models.compliance_with_criterias_dto import ComplianceWithCriteriasDto
from legit_api_client.models.container_image_dto import ContainerImageDto
from legit_api_client.models.container_image_version_dto import ContainerImageVersionDto
from legit_api_client.models.container_to_cloud_resource_operation_dto import ContainerToCloudResourceOperationDto
from legit_api_client.models.container_to_repository_operation_dto import ContainerToRepositoryOperationDto
from legit_api_client.models.control_classification import ControlClassification
from legit_api_client.models.control_source_type import ControlSourceType
from legit_api_client.models.control_type import ControlType
from legit_api_client.models.correlated_cloud_instance import CorrelatedCloudInstance
from legit_api_client.models.correlated_repository_dto import CorrelatedRepositoryDto
from legit_api_client.models.create_automatic_check_dto import CreateAutomaticCheckDto
from legit_api_client.models.create_issues_tag_dto import CreateIssuesTagDto
from legit_api_client.models.create_product_unit_bad_request_dto import CreateProductUnitBadRequestDto
from legit_api_client.models.create_product_unit_dto import CreateProductUnitDto
from legit_api_client.models.create_tag_dto import CreateTagDto
from legit_api_client.models.create_workspace_dto import CreateWorkspaceDto
from legit_api_client.models.create_workspace_group_dto import CreateWorkspaceGroupDto
from legit_api_client.models.custom_field_bool_type_dto import CustomFieldBoolTypeDto
from legit_api_client.models.custom_field_date_type_dto import CustomFieldDateTypeDto
from legit_api_client.models.custom_field_dto import CustomFieldDto
from legit_api_client.models.custom_field_dto_type import CustomFieldDtoType
from legit_api_client.models.custom_field_entity import CustomFieldEntity
from legit_api_client.models.custom_field_file_type_dto import CustomFieldFileTypeDto
from legit_api_client.models.custom_field_identity_type_dto import CustomFieldIdentityTypeDto
from legit_api_client.models.custom_field_number_type_dto import CustomFieldNumberTypeDto
from legit_api_client.models.custom_field_text_type_dto import CustomFieldTextTypeDto
from legit_api_client.models.custom_field_type import CustomFieldType
from legit_api_client.models.customer_facing_issue_dto import CustomerFacingIssueDto
from legit_api_client.models.customer_facing_issue_source_dto import CustomerFacingIssueSourceDto
from legit_api_client.models.customer_facing_issues_page_dto import CustomerFacingIssuesPageDto
from legit_api_client.models.dast_confidence_level import DastConfidenceLevel
from legit_api_client.models.dependency_fix_type import DependencyFixType
from legit_api_client.models.detailed_sdlc_asset_information_dto import DetailedSdlcAssetInformationDto
from legit_api_client.models.discovered_sdlc_asset_dto import DiscoveredSdlcAssetDto
from legit_api_client.models.discovery_connection_evidence_type import DiscoveryConnectionEvidenceType
from legit_api_client.models.framework_policy_type import FrameworkPolicyType
from legit_api_client.models.get_custom_fields_response_dto import GetCustomFieldsResponseDto
from legit_api_client.models.get_sdlc_asset_graph_evidence_by_ids_response_dto import GetSdlcAssetGraphEvidenceByIdsResponseDto
from legit_api_client.models.google_container_registry_integration_create_dto import GoogleContainerRegistryIntegrationCreateDto
from legit_api_client.models.google_container_registry_integration_edit_dto import GoogleContainerRegistryIntegrationEditDto
from legit_api_client.models.integration_bad_response_dto import IntegrationBadResponseDto
from legit_api_client.models.integration_dto import IntegrationDto
from legit_api_client.models.integration_error import IntegrationError
from legit_api_client.models.integration_failing_reason import IntegrationFailingReason
from legit_api_client.models.integration_management_dto import IntegrationManagementDto
from legit_api_client.models.integration_status import IntegrationStatus
from legit_api_client.models.integration_type import IntegrationType
from legit_api_client.models.issue_assignment import IssueAssignment
from legit_api_client.models.issue_closing_location_dto import IssueClosingLocationDto
from legit_api_client.models.issue_comment_dto import IssueCommentDto
from legit_api_client.models.issue_count_by_severity_dto import IssueCountBySeverityDto
from legit_api_client.models.issue_dto import IssueDto
from legit_api_client.models.issue_ignoring_reason_dto import IssueIgnoringReasonDto
from legit_api_client.models.issue_opening_reason_dto import IssueOpeningReasonDto
from legit_api_client.models.issue_origin_dto import IssueOriginDto
from legit_api_client.models.issue_origin_params import IssueOriginParams
from legit_api_client.models.issue_sorting_column import IssueSortingColumn
from legit_api_client.models.issue_status import IssueStatus
from legit_api_client.models.issue_tag_dto import IssueTagDto
from legit_api_client.models.issue_ticketing_dto import IssueTicketingDto
from legit_api_client.models.issue_type import IssueType
from legit_api_client.models.issues_tag_dto import IssuesTagDto
from legit_api_client.models.jenkins_integration_create_dto import JenkinsIntegrationCreateDto
from legit_api_client.models.jenkins_integration_edit_dto import JenkinsIntegrationEditDto
from legit_api_client.models.legit_score_category_dto import LegitScoreCategoryDto
from legit_api_client.models.legit_score_dto import LegitScoreDto
from legit_api_client.models.legit_score_grade import LegitScoreGrade
from legit_api_client.models.legit_score_requirement_dto import LegitScoreRequirementDto
from legit_api_client.models.legit_score_requirement_group_type import LegitScoreRequirementGroupType
from legit_api_client.models.legit_score_requirement_type import LegitScoreRequirementType
from legit_api_client.models.list_sort_direction import ListSortDirection
from legit_api_client.models.manual_check_dto import ManualCheckDto
from legit_api_client.models.origin_type import OriginType
from legit_api_client.models.patch_legit_issue_assignee_dto import PatchLegitIssueAssigneeDto
from legit_api_client.models.patch_legit_issue_status_dto import PatchLegitIssueStatusDto
from legit_api_client.models.patch_legit_issue_unified_status_dto import PatchLegitIssueUnifiedStatusDto
from legit_api_client.models.patch_legit_issues_status_dto import PatchLegitIssuesStatusDto
from legit_api_client.models.patch_product_unit_custom_field_by_name import PatchProductUnitCustomFieldByName
from legit_api_client.models.patch_product_unit_custom_field_dto import PatchProductUnitCustomFieldDto
from legit_api_client.models.patch_product_unit_custom_fields_by_name_dto import PatchProductUnitCustomFieldsByNameDto
from legit_api_client.models.patch_product_unit_custom_fields_dto import PatchProductUnitCustomFieldsDto
from legit_api_client.models.patch_product_unit_dto import PatchProductUnitDto
from legit_api_client.models.patch_security_champion_id_dto import PatchSecurityChampionIdDto
from legit_api_client.models.permission_meta_type import PermissionMetaType
from legit_api_client.models.policy_dto import PolicyDto
from legit_api_client.models.problem_details import ProblemDetails
from legit_api_client.models.product_connection_type import ProductConnectionType
from legit_api_client.models.product_tree_node_dto import ProductTreeNodeDto
from legit_api_client.models.product_unit_asset_dto import ProductUnitAssetDto
from legit_api_client.models.product_unit_dto import ProductUnitDto
from legit_api_client.models.product_unit_dto_custom_fields_value import ProductUnitDtoCustomFieldsValue
from legit_api_client.models.product_unit_environment import ProductUnitEnvironment
from legit_api_client.models.product_unit_name_dto import ProductUnitNameDto
from legit_api_client.models.product_unit_type import ProductUnitType
from legit_api_client.models.repositories_to_containers_operation_dto import RepositoriesToContainersOperationDto
from legit_api_client.models.repository_control_dto import RepositoryControlDto
from legit_api_client.models.repository_directory import RepositoryDirectory
from legit_api_client.models.repository_dto import RepositoryDto
from legit_api_client.models.repository_group_dto import RepositoryGroupDto
from legit_api_client.models.repository_visibility import RepositoryVisibility
from legit_api_client.models.scm_type import ScmType
from legit_api_client.models.sdlc_asset_dto import SdlcAssetDto
from legit_api_client.models.sdlc_asset_graph_asset_dto import SdlcAssetGraphAssetDto
from legit_api_client.models.sdlc_asset_graph_dto import SdlcAssetGraphDto
from legit_api_client.models.sdlc_asset_graph_evidence_dto import SdlcAssetGraphEvidenceDto
from legit_api_client.models.sdlc_asset_graph_link_dto import SdlcAssetGraphLinkDto
from legit_api_client.models.sdlc_asset_graph_link_dto_evidences import SdlcAssetGraphLinkDtoEvidences
from legit_api_client.models.sdlc_asset_meta_type import SdlcAssetMetaType
from legit_api_client.models.sdlc_asset_type import SdlcAssetType
from legit_api_client.models.secret_issue_validity_status import SecretIssueValidityStatus
from legit_api_client.models.severity import Severity
from legit_api_client.models.snoozed_type import SnoozedType
from legit_api_client.models.tag_dto import TagDto
from legit_api_client.models.tag_source import TagSource
from legit_api_client.models.user_dto import UserDto
from legit_api_client.models.user_permission import UserPermission
from legit_api_client.models.user_role import UserRole
from legit_api_client.models.workspace_created_dto import WorkspaceCreatedDto
from legit_api_client.models.workspace_dto import WorkspaceDto
from legit_api_client.models.workspace_group_dto import WorkspaceGroupDto
from legit_api_client.models.workspace_group_tree_node_dto import WorkspaceGroupTreeNodeDto
from legit_api_client.models.workspace_hierarchy_dto import WorkspaceHierarchyDto
from legit_api_client.models.workspace_tree_node_dto import WorkspaceTreeNodeDto
from legit_api_client.models.workspace_type import WorkspaceType
