# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AwsRegion(str, Enum):
    """
    AwsRegion
    """

    """
    allowed enum values
    """
    USEAST2 = 'UsEast2'
    USEAST1 = 'UsEast1'
    USWEST1 = 'UsWest1'
    USWEST2 = 'UsWest2'
    AFSOUTH1 = 'AfSouth1'
    APEAST1 = 'ApEast1'
    APSOUTH2 = 'ApSouth2'
    APSOUTHEAST3 = 'ApSoutheast3'
    APSOUTH1 = 'ApSouth1'
    APNORTHEAST3 = 'ApNortheast3'
    APNORTHEAST2 = 'ApNortheast2'
    APSOUTHEAST1 = 'ApSoutheast1'
    APSOUTHEAST2 = 'ApSoutheast2'
    APNORTHEAST1 = 'ApNortheast1'
    CACENTRAL1 = 'CaCentral1'
    EUCENTRAL1 = 'EuCentral1'
    EUWEST1 = 'EuWest1'
    EUWEST2 = 'EuWest2'
    EUSOUTH1 = 'EuSouth1'
    EUWEST3 = 'EuWest3'
    EUSOUTH2 = 'EuSouth2'
    EUNORTH1 = 'EuNorth1'
    EUCENTRAL2 = 'EuCentral2'
    MESOUTH1 = 'MeSouth1'
    MECENTRAL1 = 'MeCentral1'
    SAEAST1 = 'SaEast1'
    USGOVEAST1 = 'UsGovEast1'
    USGOVWEST1 = 'UsGovWest1'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AwsRegion from a JSON string"""
        return cls(json.loads(json_str))


