# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.compliance_report_dto import ComplianceReportDto

class TestComplianceReportDto(unittest.TestCase):
    """ComplianceReportDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComplianceReportDto:
        """Test ComplianceReportDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComplianceReportDto`
        """
        model = ComplianceReportDto()
        if include_optional:
            return ComplianceReportDto(
                workspaces = [
                    legit_api_client.models.compliance_report_workspace_dto.ComplianceReportWorkspaceDto(
                        id = '', 
                        name = '', )
                    ],
                integrations = [
                    legit_api_client.models.compliance_report_integration_dto.ComplianceReportIntegrationDto(
                        id = '', 
                        name = '', 
                        integration_type = '', )
                    ],
                requirements = [
                    legit_api_client.models.compliance_report_requirement_dto.ComplianceReportRequirementDto(
                        policy = '', 
                        policy_name = '', 
                        criteria = '', 
                        sub_criteria = '', 
                        requirement = '', 
                        passed = True, 
                        evaluation_started = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        evaluation_ended = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return ComplianceReportDto(
        )
        """

    def testComplianceReportDto(self):
        """Test ComplianceReportDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
