# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ProductConnectionType(str, Enum):
    """
    ProductConnectionType
    """

    """
    allowed enum values
    """
    REPOSITORY = 'Repository'
    REPOSITORYGROUP = 'RepositoryGroup'
    INTEGRATION = 'Integration'
    REPOSITORYNAMESUBSTRING = 'RepositoryNameSubstring'
    REPOSITORYCONFIGURATIONFILE = 'RepositoryConfigurationFile'
    REPOSITORYQUERY = 'RepositoryQuery'
    REPOSITORYDIRECTORY = 'RepositoryDirectory'
    REPOSITORYCOLLABORATOR = 'RepositoryCollaborator'
    REPOSITORYCONTAINER = 'RepositoryContainer'
    WEBAPPLICATION = 'WebApplication'
    WEBAPPLICATIONQUERY = 'WebApplicationQuery'
    CONTAINER = 'Container'
    CONTAINERQUERY = 'ContainerQuery'
    COLLABORATOR = 'Collaborator'
    COLLABORATORQUERY = 'CollaboratorQuery'
    APPSECPROJECT = 'AppSecProject'
    APPSECPROJECTQUERY = 'AppSecProjectQuery'
    AGGREGATEDHOST = 'AggregatedHost'
    CLOUDCOMPUTERESOURCEQUERY = 'CloudComputeResourceQuery'
    CLOUDCOMPUTERESOURCE = 'CloudComputeResource'
    NESTEDPRODUCTREPOSITORY = 'NestedProductRepository'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ProductConnectionType from a JSON string"""
        return cls(json.loads(json_str))


