# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.workspaces_api import WorkspacesApi


class TestWorkspacesApi(unittest.TestCase):
    """WorkspacesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspacesApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_workspaces_get(self) -> None:
        """Test case for api_v10_workspaces_get

        Get all workspaces
        """
        pass

    def test_api_v10_workspaces_group_post(self) -> None:
        """Test case for api_v10_workspaces_group_post

        Create new workspace group
        """
        pass

    def test_api_v10_workspaces_hierarchy_get(self) -> None:
        """Test case for api_v10_workspaces_hierarchy_get

        Get workspace hierarchy
        """
        pass

    def test_api_v10_workspaces_id_delete(self) -> None:
        """Test case for api_v10_workspaces_id_delete

        Delete workspace
        """
        pass

    def test_api_v10_workspaces_id_get(self) -> None:
        """Test case for api_v10_workspaces_id_get

        Get workspace by id
        """
        pass

    def test_api_v10_workspaces_permissions_post(self) -> None:
        """Test case for api_v10_workspaces_permissions_post

        Add permissions to workspace/group
        """
        pass

    def test_api_v10_workspaces_post(self) -> None:
        """Test case for api_v10_workspaces_post

        Create new workspace
        """
        pass

    def test_api_v10_workspaces_workspace_id_integrations_get(self) -> None:
        """Test case for api_v10_workspaces_workspace_id_integrations_get

        Get integrations by workspace id
        """
        pass


if __name__ == '__main__':
    unittest.main()
