# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.compliance_requirement_dto import ComplianceRequirementDto

class TestComplianceRequirementDto(unittest.TestCase):
    """ComplianceRequirementDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComplianceRequirementDto:
        """Test ComplianceRequirementDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComplianceRequirementDto`
        """
        model = ComplianceRequirementDto()
        if include_optional:
            return ComplianceRequirementDto(
                id = '',
                requirement_name = '',
                title = '',
                description = '',
                manual_checks = [
                    legit_api_client.models.manual_check_dto.ManualCheckDto(
                        id = '', 
                        name = '', )
                    ],
                automatic_checks = [
                    legit_api_client.models.automatic_check_dto.AutomaticCheckDto(
                        id = '', 
                        policy_name = '', 
                        title = '', 
                        category = '', 
                        type = null, )
                    ]
            )
        else:
            return ComplianceRequirementDto(
        )
        """

    def testComplianceRequirementDto(self):
        """Test ComplianceRequirementDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
