# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class IssueType(str, Enum):
    """
    IssueType
    """

    """
    allowed enum values
    """
    MISCONFIGURATION = 'Misconfiguration'
    SECRET = 'Secret'
    IAC = 'IaC'
    INCIDENT = 'Incident'
    CONTROLS = 'Controls'
    PIPELINE = 'Pipeline'
    DEPENDENCIES = 'Dependencies'
    SAST = 'Sast'
    VULNERABLEASSETS = 'VulnerableAssets'
    OTHER = 'Other'
    CONTAINERSCANNING = 'ContainerScanning'
    DAST = 'Dast'
    AIRISKS = 'AiRisks'
    INFRASTRUCTURE = 'Infrastructure'
    APISECURITY = 'ApiSecurity'
    PENTEST = 'Pentest'
    CLOUD = 'Cloud'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of IssueType from a JSON string"""
        return cls(json.loads(json_str))


