# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.asset_connection_dto import AssetConnectionDto

class TestAssetConnectionDto(unittest.TestCase):
    """AssetConnectionDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AssetConnectionDto:
        """Test AssetConnectionDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AssetConnectionDto`
        """
        model = AssetConnectionDto()
        if include_optional:
            return AssetConnectionDto(
                evidence_type = 'Unknown',
                first_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                detailed_sdlc_asset = legit_api_client.models.detailed_sdlc_asset_information_dto.DetailedSdlcAssetInformationDto(
                    sdlc_asset = null, 
                    name = '', 
                    issues_count = 56, 
                    setup_success_status_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    highest_severity = null, 
                    source_type = null, )
            )
        else:
            return AssetConnectionDto(
        )
        """

    def testAssetConnectionDto(self):
        """Test AssetConnectionDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
