# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.product_units_api import ProductUnitsApi


class TestProductUnitsApi(unittest.TestCase):
    """ProductUnitsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProductUnitsApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_products_get(self) -> None:
        """Test case for api_v10_products_get

        Get all Product Units
        """
        pass

    def test_api_v10_products_id_assets_get(self) -> None:
        """Test case for api_v10_products_id_assets_get

        Get Product Unit Assets
        """
        pass

    def test_api_v10_products_id_custom_fields_by_name_patch(self) -> None:
        """Test case for api_v10_products_id_custom_fields_by_name_patch

        Update Product Unit Custom Fields By Custom Field Name
        """
        pass

    def test_api_v10_products_id_custom_fields_patch(self) -> None:
        """Test case for api_v10_products_id_custom_fields_patch

        Update Product Unit Custom Fields by ID
        """
        pass

    def test_api_v10_products_id_delete(self) -> None:
        """Test case for api_v10_products_id_delete

        Delete Product Unit
        """
        pass

    def test_api_v10_products_id_get(self) -> None:
        """Test case for api_v10_products_id_get

        Get Product Unit by id
        """
        pass

    def test_api_v10_products_id_patch(self) -> None:
        """Test case for api_v10_products_id_patch

        Update Product Unit
        """
        pass

    def test_api_v10_products_issuescount_get(self) -> None:
        """Test case for api_v10_products_issuescount_get

        Get product units issue count by severity
        """
        pass

    def test_api_v10_products_post(self) -> None:
        """Test case for api_v10_products_post

        Create new Product Unit
        """
        pass


if __name__ == '__main__':
    unittest.main()
