# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.policy_dto import PolicyDto

class TestPolicyDto(unittest.TestCase):
    """PolicyDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyDto:
        """Test PolicyDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyDto`
        """
        model = PolicyDto()
        if include_optional:
            return PolicyDto(
                id = '',
                policy_name = '',
                issue_type = 'Misconfiguration',
                severity = 'Low',
                original_severity = 'Low',
                category = 'Unknown',
                title = '',
                description = '',
                compliances = [
                    ''
                    ],
                is_disabled = True,
                is_user_created = True,
                is_locked = True,
                target_origin_type = 'Collaborator',
                target_scm_types = [
                    'GitHubEnterpriseServer'
                    ],
                open_issues_count = 56,
                definition_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                source = '',
                remediation = ''
            )
        else:
            return PolicyDto(
        )
        """

    def testPolicyDto(self):
        """Test PolicyDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
