# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.discovered_sdlc_asset_dto import DiscoveredSdlcAssetDto

class TestDiscoveredSdlcAssetDto(unittest.TestCase):
    """DiscoveredSdlcAssetDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DiscoveredSdlcAssetDto:
        """Test DiscoveredSdlcAssetDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DiscoveredSdlcAssetDto`
        """
        model = DiscoveredSdlcAssetDto()
        if include_optional:
            return DiscoveredSdlcAssetDto(
                sdlc_asset = legit_api_client.models.sdlc_asset_dto.SdlcAssetDto(
                    id = '', 
                    sdlc_asset_type = null, 
                    sdlc_asset_meta_type_display_text = '', 
                    is_integrated = True, 
                    setup_success_status_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    integration_id = '', 
                    url = '', 
                    urls = [
                        ''
                        ], 
                    owner = '', ),
                connections = [
                    legit_api_client.models.asset_connection_dto.AssetConnectionDto(
                        evidence_type = null, 
                        first_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        detailed_sdlc_asset = null, )
                    ]
            )
        else:
            return DiscoveredSdlcAssetDto(
        )
        """

    def testDiscoveredSdlcAssetDto(self):
        """Test DiscoveredSdlcAssetDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
