# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.repository_dto import RepositoryDto

class TestRepositoryDto(unittest.TestCase):
    """RepositoryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepositoryDto:
        """Test RepositoryDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepositoryDto`
        """
        model = RepositoryDto()
        if include_optional:
            return RepositoryDto(
                id = '',
                name = '',
                url = '',
                visibility = 'Public',
                is_active = True,
                is_archived = True,
                owner = legit_api_client.models.collaborator_dto.CollaboratorDto(
                    id = '', 
                    username = '', 
                    name = '', 
                    display_name = '', 
                    is_admin = True, 
                    email = '', 
                    last_active_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    browse_url = '', ),
                tags = [
                    legit_api_client.models.tag_dto.TagDto(
                        id = '', 
                        name = '', 
                        source = '', )
                    ],
                product_units = [
                    legit_api_client.models.product_unit_name_dto.ProductUnitNameDto(
                        id = '', 
                        name = '', )
                    ],
                issues_count = 56,
                lines_count = 56,
                score = 1.337,
                score_out_of100 = 1.337,
                group = legit_api_client.models.repository_group_dto.RepositoryGroupDto(
                    id = '', 
                    name = '', 
                    integration_id = '', )
            )
        else:
            return RepositoryDto(
        )
        """

    def testRepositoryDto(self):
        """Test RepositoryDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
