# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.repositories_api import RepositoriesApi


class TestRepositoriesApi(unittest.TestCase):
    """RepositoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RepositoriesApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_repositories_get(self) -> None:
        """Test case for api_v10_repositories_get

        Get all repositories
        """
        pass

    def test_api_v10_repositories_id_controls_get(self) -> None:
        """Test case for api_v10_repositories_id_controls_get

        Get repository controls
        """
        pass

    def test_api_v10_repositories_id_get(self) -> None:
        """Test case for api_v10_repositories_id_get

        Get repository by id
        """
        pass

    def test_api_v10_repositories_id_owner_delete(self) -> None:
        """Test case for api_v10_repositories_id_owner_delete

        Delete owner from repository
        """
        pass

    def test_api_v10_repositories_id_owner_owner_id_put(self) -> None:
        """Test case for api_v10_repositories_id_owner_owner_id_put

        Set owner to repository
        """
        pass

    def test_api_v10_repositories_id_score_get(self) -> None:
        """Test case for api_v10_repositories_id_score_get

        Get repository score
        """
        pass

    def test_api_v10_repositories_repo_id_tags_tag_id_delete(self) -> None:
        """Test case for api_v10_repositories_repo_id_tags_tag_id_delete

        Remove tag from repository
        """
        pass

    def test_api_v10_repositories_repo_id_tags_tag_id_post(self) -> None:
        """Test case for api_v10_repositories_repo_id_tags_tag_id_post

        Add tag to repository
        """
        pass

    def test_api_v10_repositories_score_get(self) -> None:
        """Test case for api_v10_repositories_score_get

        Get repositories score
        """
        pass


if __name__ == '__main__':
    unittest.main()
